@@ -22,7 +22,8 @@ kable = configure({
     "client_id": 'kci_75bfe76dea214218be408fe6fa241f07',
     "client_secret": 'sk_test.jjrhHXZL.XdSSvBt22dKQdmMvjpiQ9F9v1DGtw26h',
     "environment": 'TEST',
-    "base_url": 'https://something.com'
+    "base_url": 'https://test.kableapi.com',
+    "debug": "true"
 })
 
 
